@@ -18,7 +18,7 @@ portage.proxy.lazyimport.lazyimport(globals(),
 	'portage.util:atomic_ofstream,ensure_dirs,normalize_path,' + \
 		'writemsg,writemsg_stdout',
 	'portage.util.path:first_existing',
-	'portage.util._urlopen:urlopen@_urlopen',
+	'portage.util._urlopen:urlopen@_urlopen,have_pep_476@_have_pep_476',
 	'portage.versions:best,catpkgsplit,catsplit,_pkg_str',
 )
 
@@ -141,7 +141,6 @@ class bindbapi(fakedbapi):
 				return [aux_cache.get(x, "") for x in wants]
 		mysplit = mycpv.split("/")
 		mylist = []
-		tbz2name = mysplit[1]+".tbz2"
 		if not self.bintree._remotepkgs or \
 			not self.bintree.isremote(mycpv):
 			try:
@@ -852,9 +851,9 @@ class binarytree(object):
 						download_timestamp + ttl > time.time():
 						raise UseCachedCopyOfRemoteIndex()
 
-				# Don't use urlopen for https, since it doesn't support
-				# certificate/hostname verification (bug #469888).
-				if parsed_url.scheme not in ('https',):
+				# Don't use urlopen for https, unless
+				# PEP 476 is supported (bug #469888).
+				if parsed_url.scheme not in ('https',) or _have_pep_476():
 					try:
 						f = _urlopen(url, if_modified_since=local_timestamp)
 						if hasattr(f, 'headers') and f.headers.get('timestamp', ''):
@@ -966,6 +965,8 @@ class binarytree(object):
 					"\n")
 				rmt_idx = pkgindex
 			except EnvironmentError as e:
+				# This includes URLError which is raised for SSL
+				# certificate errors when PEP 476 is supported.
 				writemsg(_("\n\n!!! Error fetching binhost package" \
 					" info from '%s'\n") % _hide_url_passwd(base_url))
 				# With Python 2, the EnvironmentError message may
@@ -1448,9 +1449,10 @@ class binarytree(object):
 	@staticmethod
 	def _parse_build_id(filename):
 		build_id = -1
-		hyphen = filename.rfind("-", 0, -6)
+		suffixlen = len(".xpak")
+		hyphen = filename.rfind("-", 0, -(suffixlen + 1))
 		if hyphen != -1:
-			build_id = filename[hyphen+1:-5]
+			build_id = filename[hyphen+1:-suffixlen]
 		try:
 			build_id = long(build_id)
 		except ValueError:
@@ -1497,7 +1499,7 @@ class binarytree(object):
 		if self._remote_has_index:
 			rel_url = self._remotepkgs[instance_key].get("PATH")
 			if not rel_url:
-				rel_url = pkgname+".tbz2"
+				rel_url = pkgname + ".tbz2"
 			remote_base_uri = self._remotepkgs[instance_key]["BASE_URI"]
 			url = remote_base_uri.rstrip("/") + "/" + rel_url.lstrip("/")
 		else:
