@@ -19,9 +19,9 @@ class BinhostHandler(object):
 
 	short_desc = "Generate a metadata index for binary packages"
 
+	@staticmethod
 	def name():
 		return "binhost"
-	name = staticmethod(name)
 
 	def __init__(self):
 		eroot = portage.settings['EROOT']
@@ -86,7 +86,9 @@ class BinhostHandler(object):
 		stale = set(metadata).difference(cpv_all)
 		for cpv in stale:
 			errors.append("'%s' is not in the repository" % cpv)
-		return errors
+		if errors:
+			return (False, errors)
+		return (True, None)
 
 	def fix(self,  **kwargs):
 		onProgress = kwargs.get('onProgress', None)
@@ -177,4 +179,4 @@ class BinhostHandler(object):
 			if maxval == 0:
 				maxval = 1
 			onProgress(maxval, maxval)
-		return None
+		return (True, None)
