@@ -1,4 +1,4 @@
-# Copyright 1998-2014 Gentoo Foundation
+# Copyright 1998-2015 Gentoo Foundation
 # Distributed under the terms of the GNU General Public License v2
 
 import signal
@@ -42,6 +42,9 @@ class PortageException(Exception):
 			else:
 				return repr(self.value)
 
+class PortageKeyError(KeyError, PortageException):
+	__doc__ = KeyError.__doc__
+
 class CorruptionError(PortageException):
 	"""Corruption indication"""
 
