@@ -1,4 +1,4 @@
-# Copyright 2005-2015 Gentoo Foundation
+# Copyright 2005-2017 Gentoo Foundation
 # Distributed under the terms of the GNU General Public License v2
 
 import logging
@@ -6,7 +6,7 @@ import subprocess
 
 import portage
 from portage import os
-from portage.util import writemsg_level
+from portage.util import writemsg_level, shlex_split
 from portage.output import create_color_func
 good = create_color_func("GOOD")
 bad = create_color_func("BAD")
@@ -50,10 +50,27 @@ class GitSync(NewBase):
 			sync_uri = sync_uri[6:]
 
 		git_cmd_opts = ""
+		if self.repo.module_specific_options.get('sync-git-env'):
+			shlexed_env = shlex_split(self.repo.module_specific_options['sync-git-env'])
+			env = dict((k, v) for k, _, v in (assignment.partition('=') for assignment in shlexed_env) if k)
+			self.spawn_kwargs['env'].update(env)
+
+		if self.repo.module_specific_options.get('sync-git-clone-env'):
+			shlexed_env = shlex_split(self.repo.module_specific_options['sync-git-clone-env'])
+			clone_env = dict((k, v) for k, _, v in (assignment.partition('=') for assignment in shlexed_env) if k)
+			self.spawn_kwargs['env'].update(clone_env)
+
 		if self.settings.get("PORTAGE_QUIET") == "1":
 			git_cmd_opts += " --quiet"
-		if self.repo.sync_depth is not None:
-			git_cmd_opts += " --depth %d" % self.repo.sync_depth
+		if self.repo.clone_depth is not None:
+			if self.repo.clone_depth != 0:
+				git_cmd_opts += " --depth %d" % self.repo.clone_depth
+		elif self.repo.sync_depth is not None:
+			if self.repo.sync_depth != 0:
+				git_cmd_opts += " --depth %d" % self.repo.sync_depth
+		else:
+			# default
+			git_cmd_opts += " --depth 1"
 		if self.repo.module_specific_options.get('sync-git-clone-extra-opts'):
 			git_cmd_opts += " %s" % self.repo.module_specific_options['sync-git-clone-extra-opts']
 		git_cmd = "%s clone%s %s ." % (self.bin_command, git_cmd_opts,
@@ -79,32 +96,21 @@ class GitSync(NewBase):
 		'''
 
 		git_cmd_opts = ""
-		quiet = self.settings.get("PORTAGE_QUIET") == "1"
-		if quiet:
+		if self.repo.module_specific_options.get('sync-git-env'):
+			shlexed_env = shlex_split(self.repo.module_specific_options['sync-git-env'])
+			env = dict((k, v) for k, _, v in (assignment.partition('=') for assignment in shlexed_env) if k)
+			self.spawn_kwargs['env'].update(env)
+
+		if self.repo.module_specific_options.get('sync-git-pull-env'):
+			shlexed_env = shlex_split(self.repo.module_specific_options['sync-git-pull-env'])
+			pull_env = dict((k, v) for k, _, v in (assignment.partition('=') for assignment in shlexed_env) if k)
+			self.spawn_kwargs['env'].update(pull_env)
+
+		if self.settings.get("PORTAGE_QUIET") == "1":
 			git_cmd_opts += " --quiet"
 		if self.repo.module_specific_options.get('sync-git-pull-extra-opts'):
 			git_cmd_opts += " %s" % self.repo.module_specific_options['sync-git-pull-extra-opts']
-		if self.repo.sync_depth is None:
-			git_cmd = "%s pull%s" % (self.bin_command, git_cmd_opts)
-		else:
-			# Since the default merge strategy typically fails when
-			# the depth is not unlimited, use `git fetch` followed by
-			# `git reset --merge`.
-			try:
-				remote_branch = portage._unicode_decode(
-					subprocess.check_output([self.bin_command, 'rev-parse',
-					'--abbrev-ref', '--symbolic-full-name', '@{upstream}'],
-					cwd=portage._unicode_encode(self.repo.location))).rstrip('\n')
-			except subprocess.CalledProcessError as e:
-				msg = "!!! git rev-parse error in %s" % self.repo.location
-				self.logger(self.xterm_titles, msg)
-				writemsg_level(msg + "\n", level=logging.ERROR, noiselevel=-1)
-				return (e.returncode, False)
-
-			git_cmd_opts += " --depth %d" % self.repo.sync_depth
-			git_cmd = "%s fetch %s%s" % (self.bin_command,
-				remote_branch.partition('/')[0], git_cmd_opts)
-
+		git_cmd = "%s pull%s" % (self.bin_command, git_cmd_opts)
 		writemsg_level(git_cmd + "\n")
 
 		rev_cmd = [self.bin_command, "rev-list", "--max-count=1", "HEAD"]
@@ -114,14 +120,6 @@ class GitSync(NewBase):
 		exitcode = portage.process.spawn_bash("cd %s ; exec %s" % (
 				portage._shell_quote(self.repo.location), git_cmd),
 			**self.spawn_kwargs)
-
-		if exitcode == os.EX_OK and self.repo.sync_depth is not None:
-			reset_cmd = [self.bin_command, 'reset', '--merge', remote_branch]
-			if quiet:
-				reset_cmd.append('--quiet')
-			exitcode = subprocess.call(reset_cmd,
-				cwd=portage._unicode_encode(self.repo.location))
-
 		if exitcode != os.EX_OK:
 			msg = "!!! git pull error in %s" % self.repo.location
 			self.logger(self.xterm_titles, msg)
@@ -132,3 +130,16 @@ class GitSync(NewBase):
 			cwd=portage._unicode_encode(self.repo.location))
 
 		return (os.EX_OK, current_rev != previous_rev)
+
+	def retrieve_head(self, **kwargs):
+		'''Get information about the head commit'''
+		if kwargs:
+			self._kwargs(kwargs)
+		rev_cmd = [self.bin_command, "rev-list", "--max-count=1", "HEAD"]
+		try:
+			ret = (os.EX_OK,
+				portage._unicode_decode(subprocess.check_output(rev_cmd,
+				cwd=portage._unicode_encode(self.repo.location))))
+		except subprocess.CalledProcessError:
+			ret = (1, False)
+		return ret
